@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: DownloadFlowController.h 2235 2006-12-10 17:36:52Z svn $
+ * $Id: DownloadFlowController.h 2285 2006-12-22 00:53:58Z svn $
  *****************************************************************************/
 
 #ifndef DOWNLOAD_FLOW_CONTROLLER_H
@@ -56,7 +56,8 @@ public:
     static DownloadFlowController *get_instance(apr_shm_t *shm);
     static apr_size_t get_memory_size();
 
-    static void dump_list(DownloadFlowController *flow_controller);
+    static const char *dump_list(apr_pool_t *pool,
+                                 DownloadFlowController *flow_controller);
 
 private:
     typedef struct Downloader {
@@ -68,7 +69,8 @@ private:
     bool downloader_list_add(apr_sockaddr_t *ip_address);
     downloader_t *downloader_list_get(apr_sockaddr_t *ip_address);
 
-    static void dump_downloader(downloader_t *downloader);
+    static const char *dump_downloader(apr_pool_t *pool,
+                                       downloader_t *downloader);
 
     apr_atomic_t lock_;
     apr_size_t downloader_count_;
