@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: PostFlowController.h 2234 2006-12-10 17:36:00Z svn $
+ * $Id: PostFlowController.h 2285 2006-12-22 00:53:58Z svn $
  *****************************************************************************/
 
 #ifndef POST_FLOW_CONTROLLER_H
@@ -56,7 +56,8 @@ public:
                                             apr_size_t min_post_interval_sec);
     static apr_size_t get_memory_size();
 
-    static void dump_list(PostFlowController *flow_controller);
+    static const char *dump_list(apr_pool_t *pool,
+                                 PostFlowController *flow_controller);
 
 private:
     typedef struct Poster {
@@ -69,7 +70,7 @@ private:
     void poster_list_clean();
     apr_time_t poster_list_is_contain(apr_sockaddr_t *ip_address) const;
 
-    static void dump_poster(poster_t *poster);
+    static const char *dump_poster(apr_pool_t *pool, poster_t *poster);
 
     apr_atomic_t lock_;
     apr_time_t min_post_interval_time_;
