@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: DownloadFlowController.cpp 2242 2006-12-11 15:35:40Z svn $
+ * $Id: DownloadFlowController.cpp 2286 2006-12-22 01:53:12Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -33,7 +33,7 @@
 #include "WriteLocker.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: DownloadFlowController.cpp 2242 2006-12-11 15:35:40Z svn $");
+SOURCE_INFO_ADD("$Id: DownloadFlowController.cpp 2286 2006-12-22 01:53:12Z svn $");
 
 /******************************************************************************
  * public メソッド
@@ -51,6 +51,10 @@ bool DownloadFlowController::add_session(apr_sockaddr_t *ip_address)
 
     WriteLocker lock(&lock_);
 
+    if (downloader_count_ == DLD_MAX_SESSION_COUNT) {
+        return false;
+    }
+
     downloader = downloader_list_get(ip_address);
 
     if (downloader == NULL) {
@@ -59,6 +63,7 @@ bool DownloadFlowController::add_session(apr_sockaddr_t *ip_address)
         if (downloader->session_count == DLD_MAX_SESSION_COUNT_PER_IP) {
             return false;
         } else {
+            downloader_count_++;
             downloader->session_count++;
             return true;
         }
@@ -73,13 +78,13 @@ void DownloadFlowController::remove_session(apr_sockaddr_t *ip_address)
 
     downloader = downloader_list_get(ip_address);
 
-    if ((downloader == NULL) || (downloader->session_count == 0)) {
+    if (downloader == NULL) {
         return;
     }
 
     downloader->session_count--;
 
-    if (downloader->session_count != 0) {
+    if (downloader_count_ != 0) {
         downloader_count_--;
     }
 }
@@ -106,14 +111,25 @@ apr_size_t DownloadFlowController::get_memory_size()
     return sizeof(DownloadFlowController);
 }
 
-void DownloadFlowController::dump_list(DownloadFlowController *flow_controller)
+const char *DownloadFlowController::dump_list(apr_pool_t *pool,
+                                              DownloadFlowController *flow_controller)
 {
+    const char *dump;
+
+    dump = apr_psprintf(pool, "%-24s : %d\n",
+                        "total count", flow_controller->downloader_count_);
     for (apr_size_t i = 0; i < DLD_MAX_SESSION_COUNT; i++) {
         if (flow_controller->downloader_list_[i].session_count == 0) {
             continue;
         }
-        dump_downloader(flow_controller->downloader_list_ + i);
+        dump = apr_pstrcat
+            (pool, dump,
+             dump_downloader(pool,
+                             flow_controller->downloader_list_ + i),
+             NULL);
     }
+
+    return dump;
 }
 
 
@@ -135,11 +151,9 @@ bool DownloadFlowController::downloader_list_add(apr_sockaddr_t *ip_address)
         }
     }
 
-#ifdef DEBUG
     if (i == DLD_MAX_SESSION_COUNT) {
         THROW(MESSAGE_BUG_FOUND);
     }
-#endif
 
     ip_address_size = get_address_size(ip_address);
 
@@ -160,6 +174,9 @@ DownloadFlowController::downloader_list_get(apr_sockaddr_t *ip_address)
                              downloader_list_[i].ip_address_size,
                              get_address(ip_address),
                              get_address_size(ip_address))) {
+            if (downloader_list_[i].session_count == 0) {
+                continue;
+            }
             return (downloader_list_ + i);
         }
     }
@@ -167,10 +184,12 @@ DownloadFlowController::downloader_list_get(apr_sockaddr_t *ip_address)
     return NULL;
 }
 
-void DownloadFlowController::dump_downloader(downloader_t *downloader)
+const char *DownloadFlowController::dump_downloader(apr_pool_t *pool,
+                                                    downloader_t *downloader)
 {
-    cerr << setw(24) << setiosflags(ios::left) << downloader->ip_address[0];
-    cerr << ": " << downloader->session_count << endl;
+    return apr_psprintf(pool, "%-24u : %d\n",
+                        downloader->ip_address[0],
+                        downloader->session_count);
 }
 
 
