@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: PostFlowController.cpp 2242 2006-12-11 15:35:40Z svn $
+ * $Id: PostFlowController.cpp 2286 2006-12-22 01:53:12Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -32,7 +32,7 @@
 #include "WriteLocker.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: PostFlowController.cpp 2242 2006-12-11 15:35:40Z svn $");
+SOURCE_INFO_ADD("$Id: PostFlowController.cpp 2286 2006-12-22 01:53:12Z svn $");
 
 /******************************************************************************
  * public メソッド
@@ -103,20 +103,27 @@ apr_size_t PostFlowController::get_memory_size()
     return sizeof(PostFlowController);
 }
 
-void PostFlowController::dump_list(PostFlowController *flow_controller)
+const char *PostFlowController::dump_list(apr_pool_t *pool,
+                                          PostFlowController *flow_controller)
 {
     apr_size_t i;
+    const char *dump;
 
     if (flow_controller->poster_top_ == flow_controller->poster_tail_) {
-        return;
+        return "";
     }
 
     i = flow_controller->poster_top_;
+    dump = "";
     do {
-        dump_poster(flow_controller->poster_list_ + i);
+        dump = apr_pstrcat
+            (pool, dump, dump_poster(pool, flow_controller->poster_list_ + i),
+             NULL);
     } while ((i = (i == 0)
               ? (ARRAY_SIZE_OF(flow_controller->poster_list_)-1)
               : (i-1)) != flow_controller->poster_tail_);
+
+    return dump;
 }
 
 
@@ -185,9 +192,10 @@ apr_time_t PostFlowController::poster_list_is_contain(apr_sockaddr_t *ip_address
     return 0;
 }
 
-void PostFlowController::dump_poster(poster_t *poster)
+const char *PostFlowController::dump_poster(apr_pool_t *pool, poster_t *poster)
 {
-    cerr << poster->ip_address[0] << endl;
+    return apr_psprintf(pool, "%-24u : %" APR_TIME_T_FMT "\n",
+                        poster->ip_address[0], poster->time);
 }
 
 
