@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: uploader_handler.cpp 2284 2006-12-20 15:43:17Z svn $
+ * $Id: uploader_handler.cpp 2287 2006-12-22 02:11:15Z svn $
  *****************************************************************************/
 
 #ifndef TEMPLATE_INSTANTIATION
@@ -56,7 +56,7 @@
 #include "SourceInfo.h"
 
 #ifndef TEMPLATE_INSTANTIATION
-SOURCE_INFO_ADD("$Id: uploader_handler.cpp 2284 2006-12-20 15:43:17Z svn $");
+SOURCE_INFO_ADD("$Id: uploader_handler.cpp 2287 2006-12-22 02:11:15Z svn $");
 #endif
 
 #define IS_REQUEST_COMMAND(arg, command) \
@@ -86,13 +86,10 @@ static const char RSS_COMMAND[]                 = "rss";
 static const char UPLOAD_COMMAND[]              = "upload";
 static const char PROGRESS_DATA_COMMAND[]       = "progress_data";
 static const char ADMIN_COMMAND[]               = "admin";
+static const char INFO_COMMAND[]                = "info";
 
 static const char PAGE_CONTENT_TYPE[]           = "text/html; charset=EUC-JP";
 
-#ifdef DEBUG
-static const char INFO_COMMAND[]                = "info";
-#endif
-
 template<class Response>
 static int redirect(typename Response::Handle *r, typename Response::Writer& o,
                     const char *url)
@@ -731,6 +728,9 @@ static int download(typename Response::Handle *r, UploaderConfig *config,
                  apr_psprintf(r->pool, "%s; filename=\"%s\"", open_mode,
                               file_name));
 
+            Response::set_env(r, "uploader_download", "");
+            Response::set_env(r, "uploader_item_id", apr_itoa(r->pool, item_id));
+
             Response::Writer::sendfile(r, item_file, uitem->get_file_size());
             finish_download(config, Response::get_remote_addr(r));
         } catch(const char *) {
@@ -849,6 +849,23 @@ static int rss(typename Response::Handle *r, UploaderConfig *config,
     return OK;
 }
 
+template<class Response>
+static int info(typename Response::Handle *r, UploaderConfig *config)
+{
+    Response::set_content_type(r, "text/plain");
+
+    if (Response::is_head_method(r)) {
+        return OK;
+    }
+
+    typename Response::Writer o(r);
+
+    o.write(config->to_string(r->pool));
+    o.finish();
+
+    return OK;
+}
+
 template<class Response>
 static int admin(typename Response::Handle *r, UploaderConfig *config,
                  const char *arg)
@@ -880,6 +897,8 @@ static int admin(typename Response::Handle *r, UploaderConfig *config,
         return download<Response>(r, config, admin_arg, true);
     } else if (strcmp(admin_command, REMOVE_COMMAND) == 0) {
         return remove<Response>(r, config, admin_arg, true);
+    } else if (IS_REQUEST_COMMAND(admin_command, INFO_COMMAND)) {
+        return info<Response>(r, config);
     }
 
     page_count = (config->get_item_list()->size() == 0)
@@ -932,24 +951,6 @@ static int admin(typename Response::Handle *r, UploaderConfig *config,
     return OK;
 }
 
-template<class Response>
-static int info(typename Response::Handle *r, UploaderConfig *config)
-{
-    Response::set_content_type(r, "text/plain");
-
-    if (Response::is_head_method(r)) {
-        return OK;
-    }
-
-    typename Response::Writer o(r);
-
-    o.write("* UploaderConfig\n");
-    o.write(config->to_string(r->pool));
-    o.finish();
-
-    return OK;
-}
-
 template<class Response>
 int uploader_command_handler(typename Response::Handle *r, UploaderConfig *config,
                              const char *arg)
@@ -998,10 +999,6 @@ int uploader_command_handler(typename Response::Handle *r, UploaderConfig *confi
         return mail_upload<Response>(r, config, arg);
     } else if (IS_REQUEST_COMMAND(command, ADMIN_COMMAND)) {
         return admin<Response>(r, config, arg);
-#ifdef DEBUG
-    } else if (IS_REQUEST_COMMAND(command, INFO_COMMAND)) {
-        return info<Response>(r, config);
-#endif
     } else {
         return error<Response>(r, config, MESSAGE_HANDLER_COMMAND_INVALID);
     }
